package Acme::MetaSyntactic::vcs;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::vcs - The vcs theme

=head1 DESCRIPTION

This theme lists popular (and not so popular) Version Control systems.

=head1 CONTRIBUTOR

Éric Cholet

Introduced in version 0.91, published on September 11, 2006.

Updated by Abigail in version 0.92, published on September 18, 2006.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
accurev
aegis
aldon_lifecycle_manager
alienbrain
allchange
allfusion_harvest_change_manager
arch
archipel
arx
asvcs
bazaar
bazaar_ng
bitkeeper
bky
changelogic
clearcase
code_co_op
codeville
cogito
controltier
CS_RCS
CSSC
cvs
cvsnt
cvs_suite
darcs
dcvs
dvs
evolution
fastcst
gat
git
ic_manage
jedi_vcs
katie
m_files
matrixone
mecasp
mercurial
meta_cvs
MKS
monotone
opencm
opencvs
Perforce
prcs
projector
QVCS
quilt
razor
RCS
rmtrcs
sccs
sdf
serena_changeman
serena_version_manager
siveco
slash_briefcase
snapshotcm
so6
sourceanywhere
sourcehaven
sourcejammer
starteam
stellation
surround_SCM
svk
Subversion
superversion
team_foundation_server
teamware
telelogic_synergy
TLIB
truechange
vault
vesta
Visual_SourceSafe
workshare_professional
