package Acme::MetaSyntactic::invasions;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::invasions - The naval and airborne invasions theme

=head1 DESCRIPTION

This list gives some codenames for naval invasions, paradrops and
operations with both a naval invasion component and an airborne
component during World War II. The list includes some operations which
were planned but not executed.

Source: among others, the I<Codeword Dictionnary>, 
Paul Adkins, Motorbooks International
(ISBN 0-7603-00368-1).

=head1 CONTRIBUTOR

Jean Forget

Introduced in version 0.92, published on September 18, 2006
(the 62nd anniversary of Market-Garden).

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Al Anvil Avalanche Baytown Coronet Detachment Dragoon Eclipse
Flintlock Gruener_Pfeil Herkules Husky Iceberg Ikarus Jubilee Leopard
Market_Garden Menace Merkur Mi Mo Oboe Olympic Overlord Roundhammer
Roundup Seeloewe Shingle Shoestring Slapstick Sledgehammer Torch
Varsity Victor Watchtower
